@@ -1,15 +1,21 @@
 import os
-import sys
 import datetime
 
-from past.builtins import execfile
-from future.utils import iteritems
+from .execfile import execfile
 import pytest
 
-from pyhamtools.qsl import get_lotw_users
+def execfile(filepath, globals=None, locals=None):
+    if globals is None:
+        globals = {}
+    globals.update({
+        "__file__": filepath,
+        "__name__": "__main__",
+    })
+    with open(filepath, 'rb') as file:
+        exec(compile(file.read(), filepath, 'exec'), globals, locals)
 
-if sys.version_info.major == 3:
-    unicode = str
+
+from pyhamtools.qsl import get_lotw_users
 
 test_dir = os.path.dirname(os.path.abspath(__file__))
 fix_dir = os.path.join(test_dir, 'fixtures')
@@ -27,8 +33,8 @@ class Test_lotw_methods:
 
         data = get_lotw_users()
         assert isinstance(data, dict)
-        for key, value in iteritems(data):
-            assert isinstance(key, unicode)
+        for key, value in data.items():
+            assert isinstance(key, str)
             assert isinstance(value, datetime.datetime )
         assert len(data) > 1000
 
